@@ -6,19 +6,19 @@
 
 #ifdef OVLB
 
-static int todelay;
+static int NEARDATA todelay;
 
 #endif /*OVLB */
 
 #ifndef OVLB
 
-OSTATIC long takeoff_mask, taking_off;
+STATIC_DCL long takeoff_mask, taking_off;
 
 #else /* OVLB */
 
-XSTATIC long takeoff_mask = 0L, taking_off = 0L;
+STATIC_OVL long NEARDATA takeoff_mask = 0L, NEARDATA taking_off = 0L;
 
-static const long takeoff_order[] = { WORN_BLINDF, 1L, /* weapon */
+static const long NEARDATA takeoff_order[] = { WORN_BLINDF, 1L, /* weapon */
 	WORN_SHIELD, WORN_GLOVES, LEFT_RING, RIGHT_RING, WORN_CLOAK,
 	WORN_HELMET, WORN_AMUL, WORN_ARMOR,
 #ifdef SHIRT
@@ -27,24 +27,16 @@ static const long takeoff_order[] = { WORN_BLINDF, 1L, /* weapon */
 	WORN_BOOTS, 0L };
 
 static void FDECL(on_msg, (struct obj *));
-#ifndef OVERLAY
-static int NDECL(Armor_on);
-static int NDECL(Boots_on);
-#endif
+STATIC_PTR int NDECL(Armor_on);
+STATIC_PTR int NDECL(Boots_on);
 static int NDECL(Cloak_on);
-#ifndef OVERLAY
-static int NDECL(Helmet_on);
-static int NDECL(Gloves_on);
-#endif
+STATIC_PTR int NDECL(Helmet_on);
+STATIC_PTR int NDECL(Gloves_on);
 static void NDECL(Amulet_on);
 static void FDECL(Ring_off_or_gone, (struct obj *, BOOLEAN_P));
-#ifndef OVERLAY
-static int FDECL(select_off, (struct obj *));
-#endif
+STATIC_PTR int FDECL(select_off, (struct obj *));
 static struct obj *NDECL(do_takeoff);
-#ifndef OVERLAY
-static int NDECL(take_off);
-#endif
+STATIC_PTR int NDECL(take_off);
 
 void
 off_msg(otmp) register struct obj *otmp; {
@@ -59,6 +51,9 @@ on_msg(otmp) register struct obj *otmp; {
 	    You("are now wearing %s.", an(xname(otmp)));
 }
 
+#endif /* OVLB */
+#ifdef OVL2
+
 boolean
 is_boots(otmp) register struct obj *otmp; {
 	return(otmp->otyp >= LOW_BOOTS &&
@@ -76,12 +71,18 @@ is_helmet(otmp) register struct obj *otmp; {
 #endif
 }
 
+#endif /* OVLB */
+#ifdef OVL2
+
 boolean
 is_gloves(otmp) register struct obj *otmp; {
 	return(otmp->otyp >= LEATHER_GLOVES &&
 	   	otmp->otyp <= GAUNTLETS_OF_DEXTERITY);
 }
 
+#endif /* OVL2 */
+#ifdef OVLB
+
 boolean
 is_cloak(otmp) register struct obj *otmp; {
 	return(otmp->otyp >= MUMMY_WRAPPING &&
@@ -99,9 +100,7 @@ is_shield(otmp) register struct obj *otmp; {
  * The Type_off() functions call setworn() themselves.
  */
 
-#ifndef OVERLAY
-static 
-#endif
+STATIC_PTR
 int
 Boots_on() {
     long oldprop =
@@ -250,9 +249,7 @@ Cloak_off() {
     return 0;
 }
 
-#ifndef OVERLAY
-static 
-#endif
+STATIC_PTR
 int
 Helmet_on() {
     switch(uarmh->otyp) {
@@ -321,9 +318,7 @@ Helmet_off() {
     return 0;
 }
 
-#ifndef OVERLAY
-static 
-#endif
+STATIC_PTR
 int
 Gloves_on() {
     long oldprop =
@@ -431,9 +426,7 @@ Shield_off() {
  * is fire resistance, and we have to immediately set HFire_resistance in worn.c
  * since worn.c will check it before returning.
  */
-#ifndef OVERLAY
-static 
-#endif
+STATIC_PTR
 int
 Armor_on()
 {
@@ -772,8 +765,8 @@ cancel_don()
 	multi = 0;
 }
 
-static const char clothes[] = {ARMOR_SYM, 0};
-static const char accessories[] = {RING_SYM, AMULET_SYM, TOOL_SYM, 0};
+static const char NEARDATA clothes[] = {ARMOR_SYM, 0};
+static const char NEARDATA accessories[] = {RING_SYM, AMULET_SYM, TOOL_SYM, 0};
 
 int
 dotakeoff() {
@@ -821,7 +814,7 @@ dotakeoff() {
 		You("can't take that off.");
 		return(0);
 	}
-	if(otmp == uarmg && uwep && uwep->cursed) {	/* myers@uwmacc */
+	if(otmp == uarmg && welded(uwep)) {
     You("seem unable to take off the gloves while holding your %s.",
 	  is_sword(uwep) ? "sword" : "weapon");
 		uwep->bknown = 1;
@@ -1327,9 +1320,7 @@ register struct obj *otmph = some_armor();
 	}
 }
 
-#ifndef OVERLAY
-static 
-#endif
+STATIC_PTR
 int
 select_off(otmp)
 register struct obj *otmp;
@@ -1435,9 +1426,7 @@ do_takeoff() {
 	return(otmp);
 }
 
-#ifndef OVERLAY
-static 
-#endif
+STATIC_PTR
 int
 take_off() {
 
