@@ -11,20 +11,20 @@
 
 #define	NOINVSYM	'#'
 
+#ifdef OVL1
 static boolean FDECL(mergable,(struct obj *,struct obj *));
-OSTATIC void FDECL(assigninvlet,(struct obj *));
 static int FDECL(merged,(struct obj *,struct obj *,int));
-OSTATIC struct obj *FDECL(mkgoldobj,(long));
-#ifndef OVERLAY
-static int FDECL(ckunpaid,(struct obj *));
-#else
-int FDECL(ckunpaid,(struct obj *));
-#endif
+#endif /* OVL1 */
+STATIC_DCL void FDECL(assigninvlet,(struct obj *));
+STATIC_DCL struct obj *FDECL(mkgoldobj,(long));
+STATIC_PTR int FDECL(ckunpaid,(struct obj *));
+#ifdef OVLB
 static boolean NDECL(wearing_armor);
 static boolean FDECL(is_worn,(struct obj *));
-static char FDECL(obj_to_let,(struct obj *));
+#endif /* OVLB */
+STATIC_DCL char FDECL(obj_to_let,(struct obj *));
 
-OSTATIC char *FDECL(xprname,(struct obj *,CHAR_P,BOOLEAN_P));
+STATIC_DCL char *FDECL(xprname,(struct obj *,CHAR_P,BOOLEAN_P));
 
 #ifdef OVLB
 
@@ -38,7 +38,7 @@ char inv_order[] = {
 	POTION_SYM, RING_SYM, WAND_SYM, TOOL_SYM, GEM_SYM,
 	ROCK_SYM, BALL_SYM, CHAIN_SYM, 0 };
 
-XSTATIC void
+STATIC_OVL void
 assigninvlet(otmp)
 register struct obj *otmp;
 {
@@ -175,6 +175,9 @@ register struct obj *obj;
 	}
 }
 
+#endif /* OVLB */
+#ifdef OVL3
+
 void
 freeinv(obj)
 register struct obj *obj;
@@ -202,6 +205,9 @@ register struct obj *obj;
 	}
 }
 
+#endif /* OVL3 */
+#ifdef OVL2
+
 /* destroy object in fobj chain (if unpaid, it remains on the bill) */
 void
 delobj(obj)
@@ -272,7 +278,7 @@ register struct gold *gold;
 #endif
 }
 
-#endif /* OVLB */
+#endif /* OVL2 */
 #ifdef OVL0
 
 struct obj *
@@ -348,6 +354,9 @@ int x, y;
 	return(FALSE);
 }
 
+#endif /* OVLB */
+#ifdef OVL2
+
 struct gold *
 g_at(x,y)
 register int x, y;
@@ -360,8 +369,11 @@ register int x, y;
 	return((struct gold *)0);
 }
 
+#endif /* OVL2 */
+#ifdef OVLB
+
 /* make dummy object structure containing gold - for temporary use only */
-XSTATIC
+STATIC_OVL
 struct obj *
 mkgoldobj(q)
 register long q;
@@ -497,6 +509,13 @@ register const char *let,*word;
 		return((struct obj *)0);
 	}
 	for(;;) {
+#ifdef MACOS
+		short	tmpflags;
+		extern short macflags;
+		
+		tmpflags = macflags;
+		macflags &= ~fDoNonKeyEvt;
+#endif
 		if(!buf[0]) {
 #ifdef REDO
 		    if(!in_doagain)
@@ -520,6 +539,9 @@ register const char *let,*word;
 			allowcnt = 2;	/* signal presence of cnt */
 			ilet = readchar();
 		}
+#ifdef MACOS
+		macflags = tmpflags;
+#endif
 		if(digit(ilet)) {
 			pline("No count allowed with this command.");
 			continue;
@@ -624,10 +646,7 @@ register const char *let,*word;
 #endif /* OVL1 */
 #ifdef OVLB
 
-#ifndef OVERLAY
-static 
-#endif
-int
+STATIC_PTR int
 ckunpaid(otmp)
 register struct obj *otmp;
 {
@@ -650,7 +669,7 @@ register struct obj *otmp;
     return(!!(otmp->owornmask & (W_ARMOR | W_RING | W_AMUL | W_TOOL | W_WEP)));
 }
 
-static const char removeables[] =
+static const char NEARDATA removeables[] =
 	{ ARMOR_SYM, WEAPON_SYM, RING_SYM, AMULET_SYM, TOOL_SYM, ' ', 0 };
 
 /* interactive version of getobj - used for Drop, Identify and */
@@ -821,7 +840,11 @@ ret:
 	return(cnt);
 }
 
-static char
+#endif /* OVLB */
+#ifdef OVL2
+
+STATIC_OVL
+char
 obj_to_let(obj)	/* should of course only be called for things in invent */
 register struct obj *obj;
 {
@@ -843,10 +866,10 @@ register struct obj *obj;
 	pline(xprname(obj, obj_to_let(obj), TRUE));
 }
 
-#endif /* OVLB */
+#endif /* OVL2 */
 #ifdef OVL1
 
-XSTATIC char *
+STATIC_OVL char *
 xprname(obj,let,dot)
 register struct obj *obj;
 register char let;
@@ -1340,6 +1363,9 @@ register struct obj *obj;
 	delobj(otmp);
 }
 
+#endif /* OVLB */
+#ifdef OVL1
+
 /*
  * Convert from a symbol to a string for printing object classes
  *
@@ -1350,7 +1376,7 @@ register struct obj *obj;
  *	WAND_SYM, [SPBOOK_SYM], RING_SYM, GEM_SYM, 0 };
  */
 
-static const char *names[] = {
+static const char NEARDATA *names[] = {
 	"Illegal objects", "Amulets", "Comestibles", "Weapons",
 	"Tools", "Iron balls", "Chains", "Boulders/Statues", "Armor",
 	"Potions", "Scrolls", "Wands",
@@ -1365,7 +1391,7 @@ char let;
 {
 	const char *pos = index(obj_symbols, let);
 	/* arbitrary buffer size by Tom May (tom@uw-warp) */
-	static char *buf = NULL;
+	static char NEARDATA *buf = NULL;
 
 	if (buf == NULL)
 	    buf = (char *) alloc ((unsigned)(strlen(HI)+17+strlen(HE)));
@@ -1383,6 +1409,9 @@ char let;
 	return (buf);
 }
 
+#endif /* OVL1 */
+#ifdef OVLB
+
 void
 reassign()
 {
